# Searches

Types:

```python
from find_ai.types import SearchCreateResponse, SearchRetrieveResponse
```

Methods:

- <code title="post /v1/searches">client.searches.<a href="./src/find_ai/resources/searches.py">create</a>(\*\*<a href="src/find_ai/types/search_create_params.py">params</a>) -> <a href="./src/find_ai/types/search_create_response.py">SearchCreateResponse</a></code>
- <code title="get /v1/searches/{id}">client.searches.<a href="./src/find_ai/resources/searches.py">retrieve</a>(id) -> <a href="./src/find_ai/types/search_retrieve_response.py">SearchRetrieveResponse</a></code>
